# API Reference

## watchmaker

```eval_rst
.. automodule:: watchmaker
```

### watchmaker.managers

```eval_rst
.. automodule:: watchmaker.managers
```

#### watchmaker.managers.base

```eval_rst
.. automodule:: watchmaker.managers.base
```

#### watchmaker.managers.workers

```eval_rst
.. automodule:: watchmaker.managers.workers
```

### watchmaker.workers

```eval_rst
.. automodule:: watchmaker.workers
```

#### watchmaker.workers.salt

```eval_rst
.. automodule:: watchmaker.workers.salt
```

#### watchmaker.workers.yum

```eval_rst
.. automodule:: watchmaker.workers.yum
```
